//
//  SITOutdoorLocationOptions.h
//  SitumSDK
//
//  Created by Adrián Rodríguez on 24/01/2020.
//  Copyright © 2020 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 Building detector strategy to find the building to start the indoor positioning. Default value is GPSProximity.
 */
typedef NS_ENUM(NSInteger, kSITBuildingDetector)
{
    /// Detect the nearest building using the GPS location distance to the building
    kSITGpsProximity = 0,
    /// Detect the building using BLE scans
    kSITBLE,
};

/**
 Outdoor location options used only in indoor-outdoor mode
*/
@interface SITOutdoorLocationOptions : NSObject <NSCopying>

/**
 Building detector strategy to find the building to start the indoor positioning
*/
@property (nonatomic) kSITBuildingDetector buildingDetector;

/**
 Minimum accuracy required, in meters, for an outdoor position to be returned through the LocationManager delegate.
 Default value is zero, so all locations will be returned regardless of its accuracy.
 This parameter only accepts positive values. If a negative value is used, it will be ignored.
 */
@property (nonatomic) NSInteger minimumOutdoorLocationAccuracy;

/**
 Controls if the building selection stage should take into account building detection geofences. These building detection geofences are configured from the dashboard and must have a custom field with the key "trainer_metadata" and value "{ "passable":"True", "use_gps":"True"}".
 This mode is useful only for a `buildingDetector` of type kSITBLE.
 When activating this mode you should set `SITLocationRequest.useGps` to YES in the `SITLocationRequest` in order obtain proper locations inside these building detection geofences.
 */
@property (nonatomic) BOOL useGeofencesInBuildingSelector;

@end

